@@ -13,7 +13,7 @@ INTERVAL = 1
 LOG_LEVEL = 'INFO'
 MIN_HEIGHT = 0
 OUTPUT = 'iptvtools.m3u'
-SORT_KEYS = ['tvg-id', 'height', 'title']
+SORT_KEYS = ['group-title', 'tvg-id', 'height', 'title']
 TEMPLATES = []
 TIMEOUT = 10
 UDPXY = None
