@@ -72,27 +72,26 @@ class Playlist():
 
     def _parse(self, sources, is_template=False):
         """Parse playlist sources."""
+        template_order = 0
         for source in sources:
-            lines = parsers.parse_content_to_lines(source)
             source_name = os.path.splitext(os.path.basename(source))[0]
-
-            if lines[0].startswith(tags.M3U):
-                res = parsers.parse_tag_m3u(lines[0])
-                if res.get('tvg-url'):
-                    self.tvg_url = res.get('tvg-url')
-                lines = lines[1:]
-
             current_item = {}
             skip = False
-            for line in lines:
-                line = line.strip()
+            is_first_line = True
+            for line in parsers.parse_content_to_lines(source):
                 if not line:
                     continue
+                if is_first_line:
+                    is_first_line = False
+                    if line.startswith(tags.M3U):
+                        res = parsers.parse_tag_m3u(line)
+                        if res.get('tvg-url'):
+                            self.tvg_url = res.get('tvg-url')
+                        continue
                 if skip:
                     skip = False
                     continue
                 if line.startswith(tags.INF):
-                    line = re.sub("\W+", "", line)
                     current_item = parsers.parse_tag_inf(line)
                     current_item = utils.unify_title_and_id(current_item)
                     current_id = current_item['id']
@@ -122,8 +121,10 @@ class Playlist():
 
                 else:
                     if is_template:
+                        template_order = template_order + 1
                         for url in self.id_url.get(current_id, []):
                             current_params = current_item['params']
+                            current_params['template-order'] = template_order
                             self.data[url]['params'].update(current_params)
                             self.data[url]['title'] = current_item['title']
                     else:
@@ -160,7 +161,7 @@ class Playlist():
             pbar.write(f'{url}, {status}!')
 
     def __custom_sort(self, url):
-        """Sort by tvg-id, resolution and title."""
+        """Sort by tvg-id, resolution, template-order and title."""
         res = []
         for key in self.args.sort_keys:
             entry = self.data[url]
@@ -170,4 +171,8 @@ class Playlist():
                 res.append(entry.get(key, ''))
             elif key == 'tvg-id':
                 res.append(int(entry['params'].get(key) or sys.maxsize))
+            elif key == 'template-order':
+                res.append(int(entry['params'].get(key) or sys.maxsize))
+            elif key == 'group-title':
+                res.append(entry['params'].get(key) or '')
         return res
